#   comment -*-coding: iso-8859-9;-*-
POSIX uyumlu bir kabuga girerken etkin olacak ayarlar
END
POSIX uyumlu bir kabua girerken etkin olacak ayarlar
END

print <<"EOF";
# Set the Turkish locale.
LANG=$LOCALE
export LANG

# Follow POSIX for some locale items.
#LC_MESSAGES=C
#LC_TIME=C
#LC_NUMERIC=C
#export LC_MESSAGES
#export LC_TIME
#export LC_NUMERIC

# Charset for MIME headers.
MM_CHARSET=$ENCODING
export MM_CHARSET

# Encoding for SGML-DSSSL processing.
SP_ENCODING=$ENCODING
export SP_ENCODING

EOF

if ($EXTENDED) {
	print <<"EOF";
# Set the Turkish locale.
LANG=$LOCALE
export LANG

# Setup the console font and keyboard.
KTYPE=$KTYPE
FONT=$CFONT

EOF
	print <<'EOF';
if [ "`locale charmap 2>/dev/null`" = "UTF-8" ]; then
	case "$KTYPE" in
		q|Q)		keyb="trqu"   ;;
		f|F)		keyb="trfu"   ;;
		alt|qalt|QALT)	keyb="tralt"  ;;
		*)		keyb="trqu"   ;;
	esac
	umode="start"
else
	case "$KTYPE" in
		q|Q)		keyb="trq"    ;;
		f|F)		keyb="trf"    ;;
		alt|qalt|QALT)	keyb="tralt"  ;;
		*)		keyb="trq"    ;;
	esac
	umode="stop"
fi

case `tty` in
	/dev/tty[0-9]*|/dev/vc/*)
		(
		if which consolechars; then
			consolechars -f $FONT -m iso09
		else
			setfont $FONT -m trivial
		fi
		
		if which loadkeys; then
			# Prepare console mode and setup keyboard.
			if which unicode_${umode}; then
				unicode_${umode} 
			fi
			loadkeys $keyb
		fi
		) >/dev/null 2>&1
		;;
esac

EOF
}
